@@ -155,9 +155,9 @@ def find_rois_cwt(s, fs, flims, tlen, th=0, display=False, save_df=False,
     # find peaks
     cwt_width = [round(tlen*fs/wl/2)]
     npad = 5 ## seems to work with 3, but not sure
-    s_rms = np.pad(s_rms, np.int(cwt_width[0]*npad), 'reflect')  ## add pad
+    s_rms = np.pad(s_rms, np.int64(cwt_width[0]*npad), 'reflect')  ## add pad
     s_cwt = signal.cwt(s_rms, signal.ricker, cwt_width)
-    s_cwt = s_cwt[0][np.int(cwt_width[0]*npad):len(s_cwt[0])-np.int(cwt_width[0]*npad)] ## rm pad
+    s_cwt = s_cwt[0][np.int64(cwt_width[0]*npad):len(s_cwt[0])-np.int64(cwt_width[0]*npad)] ## rm pad
     # find onset and offset of sound
     segments_bin = np.array(s_cwt > th)
     onset = t[np.where(np.diff(segments_bin.astype(int)) > 0)]+t[0]  # there is delay because of the diff that needs to  be accounted
@@ -182,7 +182,7 @@ def find_rois_cwt(s, fs, flims, tlen, th=0, display=False, save_df=False,
         if save_df==True:
             df.to_csv(savefilename, sep=',', header=True, index=False)
 
-    #%% Display
+    # Display
     if display==True: 
         figsize = kwargs.pop('figsize',(12,6))
         cmap = kwargs.pop('cmap','gray')
@@ -209,7 +209,8 @@ def find_rois_cwt(s, fs, flims, tlen, th=0, display=False, save_df=False,
                 width = df.max_t[idx] - df.min_t[idx]
                 height = df.max_f[idx] - df.min_f[idx]
                 rect = patches.Rectangle(xy, width, height, lw=1, 
-                                         edgecolor='r', facecolor='none')
+                                         edgecolor='yellow', facecolor='none')
                 ax2.add_patch(rect)
         plt.show()
+    
     return df
