@@ -22,6 +22,18 @@ Conversion to sound pressure level (SPL)
     wav2leq
     pressure2leq
     psd2leq
+    
+Attenuation and active distance
+-------------------------------
+.. autosummary::
+    :toctree: generated/
+    
+    attenuation_dB
+    dBSPL_per_bin
+    detection_distance
+    pressure_at_r0
+    dBSPL_at_r0
+    apply_attenuation
 
 """
 
@@ -37,6 +49,13 @@ from .conversion_SPL import (wav2volt,
                         pressure2leq,
                         psd2leq)
 
+from .active_space import (attenuation_dB,
+                           dBSPL_per_bin,
+                           detection_distance,
+                           pressure_at_r0,
+                           dBSPL_at_r0,
+                           apply_attenuation)
+
 __all__ = [
            # conversion_SPL        
            'wav2volt',
@@ -50,4 +69,11 @@ __all__ = [
            'wav2leq',
            'pressure2leq',
            'psd2leq'
+           #active_space
+           'attenuation_dB',
+           'dBSPL_per_bin',
+           'detection_distance',
+           'pressure_at_r0',
+           'dBSPL_at_r0',
+           'apply_attenuation'
            ]
